@@ -3,6 +3,7 @@ from pyclbr import Function
 from tokenize import Double
 from typing import Dict
 from xmlrpc.client import Boolean
+
 import pyro
 import pyro.distributions as distr
 import torch
@@ -13,17 +14,17 @@ from pyro.infer import SVI
 from torch.distributions import constraints
 from sklearn.cluster import KMeans
 from tqdm import trange
-import random
 
 
 class MVNMixtureModel():
-    def __init__(self, K, data, IS=[], columns=[], lineages=[]):
+    def __init__(self, K, data, IS=[], columns=[], lineages=[], default_init=True):
         self._set_dataset(data)
         self.IS = np.array(IS)
         self.dimensions = columns # `columns` will be a list of type ["early.MNC", "mid.MNC", "early.Myeloid", "mid.Myeloid"]
         self.lineages = lineages
 
         self.K, self._N, self._T = K, self.dataset.shape[0], self.dataset.shape[1]
+        self.default_init = default_init
         self._initialize_attributes()
         self._initialize_sigma_constraint() 
 
@@ -130,6 +131,21 @@ class MVNMixtureModel():
         It performs a linear regression on the marginal distribution of each dimension and performs 
         a check on the x-intercept, to avoid negative values of y for x in [0,max_cov].
         '''
+
+        if not self.default_init:
+            self._compute_sigma_constraints()
+        
+        else:
+            self.set_sigma_constraints()
+
+
+    def set_sigma_constraints(self, slope=0.09804862, intercept=22.09327233):
+        slope_tns = torch.repeat_interleave(torch.tensor(slope), self._T)
+        intercept_tns = torch.repeat_interleave(torch.tensor(intercept), self._T)
+        self.lm = {"slope":slope_tns, "intercept":intercept_tns}
+
+
+    def _compute_sigma_constraints(self):
         self.lm = dict()
         slope, intercept = torch.zeros((self._T)), torch.zeros((self._T))
         for t in range(self._T):
@@ -176,7 +192,7 @@ class MVNMixtureModel():
 
     def run_kmeans(self, K):
         removed_idx, data_unq = self.check_input_kmeans()
-        
+
         km = KMeans(n_clusters=K, random_state=self._seed).fit(data_unq.numpy())
         assert km.n_iter_ < km.max_iter
 
@@ -184,6 +200,7 @@ class MVNMixtureModel():
         for rm in sorted(removed_idx.keys()):
             # insert 0 elements to restore the original number of obs
             clusters = np.insert(clusters, rm, 0, 0)
+
         for rm in removed_idx.keys():
             # insert in the repeated elements the correct cluster
             rpt = removed_idx[rm]  # the index of the kept row
@@ -226,9 +243,9 @@ class MVNMixtureModel():
             k_max = k_min + 1
         if k_min == k_max:
             return k_min
-        
+
         k_interval = (k_min, k_max)
-        
+
         scores = torch.zeros(k_interval[1])
         for k in range(k_interval[0], k_interval[1]):
             km = self.run_kmeans(k)
